
# This file was generated by 'versioneer.py' (0.28) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2023-04-25T01:34:53+0000",
 "dirty": false,
 "error": null,
 "full-revisionid": "7df68b77a95576850f8ac8122405b7e91dc0d7f0",
 "version": "v23.06.00a230425"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
